@@ -1,9 +1,8 @@
 #!/usr/bin/perl -w
 
 package Math::BigInt::Constant;
-my $class = "Math::BigInt::Constant";
 
-$VERSION = 1.07;
+$VERSION = 1.08;
 use Math::BigInt;
 @ISA =       qw( Math::BigInt );
 use strict;
@@ -26,8 +25,8 @@ sub copy
   {
   my $x = shift;
 
-  $x = Math::BigInt::Constant->new($x) if !ref($x);
-  my $self = Math::BigInt->copy($x);
+  return Math::BigInt->new($x) unless ref($x);
+  Math::BigInt->copy($x);
   }
 
 1;
@@ -97,6 +96,10 @@ Math::BigInt::Constant - Arbitrary sized constant integers
   $x->bxor($y);			# bit-wise exclusive or
   $x->bnot();			# bit-wise not (two's complement)
 
+  $x->bnok($k);			# n over k
+  $x->bfac();			# factorial $x!
+  $x->bexp();			# Euler's number e ** $x
+
   $x->bsqrt();			# calculate square-root
   $x->broot($y);		# calculate $y's root
   $x->blog($base);		# calculate integer logarithm
@@ -120,6 +123,7 @@ Math::BigInt::Constant - Arbitrary sized constant integers
   $x->as_int();			# return a copy of the object as BigInt
   $x->as_hex();			# return number as hex string
   $x->as_bin();			# return number as binary string
+  $x->as_oct();			# return number as octal string
 
 =head1 DESCRIPTION
 
@@ -151,16 +155,21 @@ these provide runtime checks and can be interpolated into strings:
 	print $x+2,"\n";		# dito
 	$x += 2;			# not okay, will die
 
+=head1 METHODS
+
+A C<Math::BigInt::Constant> object has all the same methods as a
+C<Math::BigInt> object.
+
 =head1 BUGS
 
 None discovered yet.
 
 =head1 SEE ALSO
 
-L<Math::BigInt>.
+L<Math::BigInt>, L<Math::BigFloat::Constant>.
 
 =head1 AUTHORS
 
-(c) by Tels L<http://bloodgate.com/> in early 2001 - 2006.
+(c) by Tels L<http://bloodgate.com/> in early 2001 - 2007.
 
 =cut
